# vis-eng
Visualisation library for producing graphics from Python's Matplotlib

This module provides several features to enhance Pyplot for animations and general graphics.

![](https://github.com/OllieBoyne/vis-eng/blob/master/examples/brach_comparison.gif)
